@@ -1,6 +1,10 @@
 crps.ensembleBMAnormal <-
-function(fit, ensembleData, nSamples=10000, seed=NULL, dates=NULL, ...) 
+function(fit, ensembleData, dates=NULL, nSamples=10000, seed=NULL, ...) 
 {
+#
+# copyright 2006-present, University of Washington. All rights reserved.
+# for terms of use, see the LICENSE file
+#
  weps <- 1.e-4
 
  erf <- function(x) 2 * pnorm(x * sqrt(2)) - 1
@@ -13,72 +17,34 @@ function(fit, ensembleData, nSamples=10000, seed=NULL, dates=NULL, ...)
 
  matchITandFH(fit,ensembleData)
 
- M <- matchEnsembleMembers(fit,ensembleData)
- nForecasts <- ensembleSize(ensembleData)
- if (!all(M == 1:nForecasts)) ensembleData <- ensembleData[,M]
+ ensembleData <- ensembleData[,matchEnsembleMembers(fit,ensembleData)]
 
-## remove instances missing all forecasts
+ M <- !dataNA(ensembleData)
+ if (!all(M)) ensembleData <- ensembleData[M,]
 
- M <- apply(ensembleForecasts(ensembleData), 1, function(z) all(is.na(z)))
- M <- M | is.na(ensembleVerifObs(ensembleData))
- ensembleData <- ensembleData[!M,]
- 
-## match specified dates with dateTable in fit
+ fitDates <- modelDates(fit)
 
- dateTable <- dimnames(fit$weights)[[2]]
+ M <- matchDates( fitDates, ensembleValidDates(ensembleData), dates)
 
- if (!is.null(dates)) {
+ if (!all(M$ens)) ensembleData <- ensembleData[M$ens,]
+ if (!all(M$fit)) fit <- fit[fitDates[M$fit]]
 
-   dates <- sort(unique(as.character(dates)))
+ dates <- modelDates(fit)
 
-   if (length(dates) > length(dateTable)) 
-     stop("parameters not available for some dates")
+ Dates <- ensembleValidDates(ensembleData)
 
-   K <- match( dates, dateTable, nomatch=0)
-
-   if (any(!K) || !length(K)) 
-     stop("parameters not available for some dates")
-
- }
- else {
-
-   dates <- dateTable
-   K <- 1:length(dateTable)
-
-  }
-
- ensDates <- ensembleValidDates(ensembleData)
-
-## match dates in data with dateTable
- if (is.null(ensDates) || all(is.na(ensDates))) {
-   if (length(dates) > 1) stop("date ambiguity")
-   nObs <- nrow(ensembleData)
-   Dates <- rep( dates, nObs)
- }
- else {
-## remove instances missing dates
-   if (any(M <- is.na(ensDates))) {
-     ensembleData <- ensembleData[!M,]
-     ensDates <- ensembleValidDates(ensembleData)
-   }
-   Dates <- as.character(ensDates)
-   L <- as.logical(match( Dates, dates, nomatch=0))
-   if (all(!L) || !length(L)) 
-     stop("model fit dates incompatible with ensemble data")
-   Dates <- Dates[L]
-   ensembleData <- ensembleData[L,]
-   nObs <- length(Dates)
- }
+ obs <- dataVerifObs(ensembleData)
+ nObs <- length(obs)
 
  Q <- as.vector(quantileForecast( fit, ensembleData, dates = dates))
  if (any(is.na(Q))) stop("NAs in forecast") # fix like ensembleBMAgamma0
 
- obs <- ensembleVerifObs(ensembleData)
+ obs <- dataVerifObs(ensembleData)
  nForecasts <- ensembleSize(ensembleData) 
- members <- ensembleMemberLabels(ensembleData)
+ members <- ensembleMembers(ensembleData)
 
  CRPS <- crpsSim <- sampleMedian <- rep(NA, nObs)
- names(crpsSim) <- names(sampleMedian) <- ensembleObsLabels(ensembleData)
+ names(crpsSim) <- names(sampleMedian) <- dataObsLabels(ensembleData)
 
  ensembleData <- ensembleForecasts(ensembleData)
 
@@ -86,16 +52,15 @@ function(fit, ensembleData, nSamples=10000, seed=NULL, dates=NULL, ...)
  for (d in dates) {
 
     l <- l + 1
-    k <- K[l]
 
-    WEIGHTS <- fit$weights[,k]
+    WEIGHTS <- fit$weights[,d]
     if (all(Wmiss <- is.na(WEIGHTS))) next
      
     SD <- if (!is.null(dim(fit$sd))) {
-            fit$sd[,k] 
+            fit$sd[,d] 
           } 
           else {
-            rep(fit$sd[k], nForecasts)
+            rep(fit$sd[d], nForecasts)
           }
 
     VAR <- SD*SD
@@ -106,7 +71,7 @@ function(fit, ensembleData, nSamples=10000, seed=NULL, dates=NULL, ...)
     
        f <- ensembleData[i,]
      
-       MEAN <- apply(rbind(1, f) * fit$biasCoefs[,,k], 2, sum)
+       MEAN <- apply(rbind(1, f) * fit$biasCoefs[,,d], 2, sum)
 
        M <- is.na(f) | Wmiss
 
